pub enum BitmexOrderType {
Market,
Limit,
Stop,
StopLimit,
MarketIfTouched,
LimitIfTouched,
Pegged,
}Expand description
Represents the available order types on BitMEX.
Variants
Market
Market order, executed immediately at current market price.
Limit
Limit order, executed only at specified price or better.
Stop
Stop Market order, triggers a market order when price reaches stop price.
StopLimit
Stop Limit order, triggers a limit order when price reaches stop price.
MarketIfTouched
Market if touched order, triggers a market order when price reaches touch price.
LimitIfTouched
Limit if touched order, triggers a limit order when price reaches touch price.
Pegged
Pegged order, price automatically tracks market.
Implementations
Sourceimpl BitmexOrderType
impl BitmexOrderType
Sourcepub fn try_from_order_type(value: OrderType) -> Result<Self>
pub fn try_from_order_type(value: OrderType) -> Result<Self>
Try to convert from Nautilus OrderType with anyhow::Result.
Errors
Returns an error if the order type is MarketToLimit (not supported by BitMEX).